#
# spec file for package bliss
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define lname   libbliss0_77
Name:           bliss
Version:        0.77
Release:        1.13
Summary:        A Tool for Computing Automorphism Groups and Canonical Labelings of Graphs
License:        LGPL-3.0-only
Group:          Productivity/Scientific/Math
URL:            https://users.aalto.fi/~tjunttil/bliss/
Source:         https://users.aalto.fi/~tjunttil/bliss/downloads/bliss-%version.zip
Patch1:         bliss-nodate.diff
Patch2:         cmake.patch
BuildRequires:  cmake >= 3.5
BuildRequires:  gcc-c++
BuildRequires:  gmp-devel
BuildRequires:  libtool
BuildRequires:  unzip

%description
bliss is a tool for computing automorphism groups and canonical forms
of graphs. It has both a command line user interface as well as C++
and C programming language APIs.

%package -n %lname
Summary:        Library for computing automorphism groups and canonical forms of graphs
Group:          System/Libraries

%description -n %lname
bliss is a tool for computing automorphism groups and canonical forms
of graphs.

%package devel
Summary:        Development files for bliss, a math library
Group:          Development/Libraries/C and C++
Requires:       %lname = %version

%description devel
bliss is a tool for computing automorphism groups and canonical forms
of graphs.

This subpackage contains libraries and header files for developing
applications that want to make use of the Bliss library.

%prep
%autosetup -p1

%build
%cmake -DUSE_GMP=ON -DBUILD_STATIC=OFF
%cmake_build

%install
%cmake_install

%post   -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%files
%license COPYING*
%_bindir/bliss*

%files -n %lname
%_libdir/libbliss.so.%version

%files devel
%doc CHANGES.txt README.txt
%_libdir/libbliss.so
%_includedir/bliss/

%changelog
* Mon Jun 21 2021 Jan Engelhardt <jengelh@inai.de>
- Set versioned cmake requirement
* Wed Jun  2 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 0.77:
  * set_color and copy methods in the C++ API
  * precise group size computation also without GNU GMP
  * no more exit-causing "fatal_errors", instead a standard exception
    is thrown
- Update to version 0.76:
  * The monolithic "graph" file is split in "abstractgraph",
    "graph" and "digraph".
  * defs.hh now contains the version number as a #define.
  * is_automorphism is now a public member of Graph and Digraph.
- Update to version 0.75:
  * Automorphism reporting and termination check functions
    are now of C++ type std::function.
  * Bignum allows one to get a copy of internal GNU GMP integer.
- Update to version 0.74:
  * Fixed a memory leak
  * Possibility to terminate the search early
  * Minor changes for better C++11 compatibility.
  * Memory allocation failures now throw std::bad_alloc
- Drop bliss-am.diff upstream uses cmake
- Add cmake.patch, allow installing the library and binary.
- Refresh bliss-nodate.diff
* Sat Aug 24 2019 Jan Engelhardt <jengelh@inai.de>
- Modernize specfile.
* Mon Dec 25 2017 jengelh@inai.de
- Correct URL line in specfile
* Thu Sep 14 2017 jengelh@inai.de
- Initial package (version 0.73) for build.opensuse.org
- Add bliss-am.diff, bliss-nodate.diff
